``eradiate.thermoprops``
========================

.. automodule:: eradiate.thermoprops

.. py:currentmodule:: eradiate.thermoprops

.. rubric:: Modules

.. autosummary::
   :recursive:
   :toctree: generated/autosummary/

   afgl_1986
   us76
   util
